import { UseErrorOptions } from "react-hooks-use-error/useError";
import useIndicators from './useIndicators';
export interface UseActionHandlerOptions extends UseErrorOptions {
    isRetryAllowed?: boolean;
    strict?: boolean;
    onStart?(): any;
    onSuccess?(data?: any): any;
    onError?(error: Error): any;
}
interface UseActionHandlerHookBase {
    reset(): void;
    error: string;
    isLoading: boolean;
    isErrored: boolean;
    indicators: ReturnType<typeof useIndicators>;
}
export type AsyncAction<ActionResult, ActionParams = undefined> = {
    onAction: ActionParams extends undefined ? () => Promise<ActionResult> : (params: ActionParams) => Promise<ActionResult>;
} & UseActionHandlerHookData<ActionResult>;
export type UseActionHandlerHookData<DataResult> = ({
    isDone: false;
    data: null;
} & UseActionHandlerHookBase) | ({
    isDone: true;
    data: DataResult;
} & UseActionHandlerHookBase);
declare function useAsyncHandler<ActionResult>(onAction: () => Promise<ActionResult>, options?: UseActionHandlerOptions): {
    execute: () => Promise<ActionResult>;
} & UseActionHandlerHookData<ActionResult>;
declare function useAsyncHandler<ActionResult, Param>(onAction: (param: Param) => Promise<ActionResult>, options?: UseActionHandlerOptions): {
    execute: typeof onAction;
} & UseActionHandlerHookData<ActionResult>;
export default useAsyncHandler;
